@@ -211,6 +211,8 @@ void HeadersRuleWidgetHandler::reset(QStackedWidget *functionStack,
         lineEdit->blockSignals(true);
         lineEdit->clear();
         lineEdit->blockSignals(false);
+        lineEdit->setClearButtonEnabled(false);
+        lineEdit->setClearButtonEnabled(true);
         valueStack->setCurrentWidget(lineEdit);
     }
 
@@ -266,6 +268,8 @@ bool HeadersRuleWidgetHandler::setRule(QStackedWidget *functionStack,
             lineEdit->blockSignals(true);
             lineEdit->setText(rule->contents());
             lineEdit->blockSignals(false);
+            lineEdit->setClearButtonEnabled(false);
+            lineEdit->setClearButtonEnabled(true);
             valueStack->setCurrentWidget(lineEdit);
         }
     }
